{% extends "base.html" %}

{% block title %}Login - aiosyslogd{% endblock %}

{% block content %}
<div class="row justify-content-center">
    <div class="col-md-4">
        <h1 class="h3 mb-3 fw-normal">Please sign in</h1>
        <form method="post">
            <div class="form-floating">
                <input type="text" class="form-control" id="username" name="username" placeholder="Username" required autofocus>
                <label for="username">Username</label>
            </div>
            <div class="form-floating">
                <input type="password" class="form-control" id="password" name="password" placeholder="Password" required>
                <label for="password">Password</label>
            </div>
            <button class="w-100 btn btn-lg btn-primary" type="submit">Sign in</button>
        </form>
    </div>
</div>
{% endblock %}
